#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-8v4aTrYsUmY2MGqVgiwZkG
key:                  pantry-0.8.3-8v4aTrYsUmY2MGqVgiwZkG
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  29222b0844ccf29665ff31e3318fe934
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-8v4aTrYsUmY2MGqVgiwZkG
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-CRLoVrOByflKEQQ5tNkVEn
    ansi-terminal-1.1-6Y22U2Ur51rJg2I79RgMg8 base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-9J0jnrjd5CE4uDITWWwOjx
    casa-types-0.0.3-H9gkZvp0GgvKQFQgmto60H
    conduit-1.3.6.1-3ZkfU3UFxE9HTVkK8cD
    conduit-extra-1.3.8-CBry4ZxjfNzDWNilco7aIQ containers-0.6.7
    crypton-1.0.4-5fA2jRD5YCU8JiTQyX4nZ5
    crypton-conduit-0.2.3-DYCuTiObLfIIIi5mAXxrLT
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-IOLkNNeWqCfG2Hld3oaE5B
    generic-deriving-1.14.7-L4kTJPfatQaUIXvXdxVU2
    hackage-security-0.6.3.2-DTWmGveHuDqDe47jTnGQEg
    hpack-0.38.0-C9h1pxR4jWLA8XHZaxn9ZR
    http-client-0.7.19-1q3y7vnpuvH51ds1r9Weyk
    http-client-tls-0.3.6.4-KIkmAPoOGiF5239aT5EBjl
    http-conduit-2.3.9.1-FDcTCktOtYxKu3CCbOTyb9
    http-download-0.2.1.0-InVVQ0UhmD7IAg3GFw9cQM
    http-types-0.12.4-DWpoveyaOeC1PmowHzh97w
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-DZsK30J0JA75RbwwKgdhQI
    path-0.9.6-EvvPSLfEt7fBsby68XTV1f
    path-io-1.8.2-4eYepSViNYh2v9MdrM3VZX
    persistent-2.14.5.2-J5QcwNMWHDSIesY2UvDstY
    persistent-sqlite-2.13.2.0-FfC0a4NIRdU1iqVvrLxxWz
    primitive-0.9.1.0-94Qnzznh8Dc4Pbexl4gZ0v
    resourcet-1.2.6-ISzbKkOS7tA59m6DqAPsM
    rio-0.1.24.0-BnqaoM9zJ4LAPcLSBaeAta
    rio-orphans-0.1.2.0-IYlhzCa4G2lGrGmd7iVqA8
    rio-prettyprint-0.1.8.0-G0QVO5QxHSkFJoVQ3WybXq
    tar-conduit-0.4.1-3DBdYIYYgB0CPYqzHZ5Zx0 text-2.0.2
    text-metrics-0.3.3-5hyiig7YYA0HgUl5HjeePz time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-EYHAsit1fL11kLRdxVRh0d
    unliftio-0.2.25.1-2In9ZMbNHRKIca2kbOdPHJ
    unordered-containers-0.2.20.1-170HxTRPWLJC6Js92iIt2k
    vector-0.13.2.0-LuonB4ieSbk1FHCVO4HoCK
    yaml-0.11.11.2-Fn9T4W0bBLID4pp6F8D3Yf
    zip-archive-0.4.3.2-8q0JLFEnmg21HzGN2uAs68

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

